/*
 * Generated by gdbus-codegen 2.43.0. DO NOT EDIT.
 *
 * The license of this code is the same as for the source it was derived from.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "gvfsvolumemonitordbus.h"

#include <string.h>
#ifdef G_OS_UNIX
#  include <gio/gunixfdlist.h>
#endif

typedef struct
{
  GDBusArgInfo parent_struct;
  gboolean use_gvariant;
} _ExtendedGDBusArgInfo;

typedef struct
{
  GDBusMethodInfo parent_struct;
  const gchar *signal_name;
  gboolean pass_fdlist;
} _ExtendedGDBusMethodInfo;

typedef struct
{
  GDBusSignalInfo parent_struct;
  const gchar *signal_name;
} _ExtendedGDBusSignalInfo;

typedef struct
{
  GDBusPropertyInfo parent_struct;
  const gchar *hyphen_name;
  gboolean use_gvariant;
} _ExtendedGDBusPropertyInfo;

typedef struct
{
  GDBusInterfaceInfo parent_struct;
  const gchar *hyphen_name;
} _ExtendedGDBusInterfaceInfo;

typedef struct
{
  const _ExtendedGDBusPropertyInfo *info;
  guint prop_id;
  GValue orig_value; /* the value before the change */
} ChangedProperty;

static void
_changed_property_free (ChangedProperty *data)
{
  g_value_unset (&data->orig_value);
  g_free (data);
}

static gboolean
_g_strv_equal0 (gchar **a, gchar **b)
{
  gboolean ret = FALSE;
  guint n;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  if (g_strv_length (a) != g_strv_length (b))
    goto out;
  for (n = 0; a[n] != NULL; n++)
    if (g_strcmp0 (a[n], b[n]) != 0)
      goto out;
  ret = TRUE;
out:
  return ret;
}

static gboolean
_g_variant_equal0 (GVariant *a, GVariant *b)
{
  gboolean ret = FALSE;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  ret = g_variant_equal (a, b);
out:
  return ret;
}

G_GNUC_UNUSED static gboolean
_g_value_equal (const GValue *a, const GValue *b)
{
  gboolean ret = FALSE;
  g_assert (G_VALUE_TYPE (a) == G_VALUE_TYPE (b));
  switch (G_VALUE_TYPE (a))
    {
      case G_TYPE_BOOLEAN:
        ret = (g_value_get_boolean (a) == g_value_get_boolean (b));
        break;
      case G_TYPE_UCHAR:
        ret = (g_value_get_uchar (a) == g_value_get_uchar (b));
        break;
      case G_TYPE_INT:
        ret = (g_value_get_int (a) == g_value_get_int (b));
        break;
      case G_TYPE_UINT:
        ret = (g_value_get_uint (a) == g_value_get_uint (b));
        break;
      case G_TYPE_INT64:
        ret = (g_value_get_int64 (a) == g_value_get_int64 (b));
        break;
      case G_TYPE_UINT64:
        ret = (g_value_get_uint64 (a) == g_value_get_uint64 (b));
        break;
      case G_TYPE_DOUBLE:
        {
          /* Avoid -Wfloat-equal warnings by doing a direct bit compare */
          gdouble da = g_value_get_double (a);
          gdouble db = g_value_get_double (b);
          ret = memcmp (&da, &db, sizeof (gdouble)) == 0;
        }
        break;
      case G_TYPE_STRING:
        ret = (g_strcmp0 (g_value_get_string (a), g_value_get_string (b)) == 0);
        break;
      case G_TYPE_VARIANT:
        ret = _g_variant_equal0 (g_value_get_variant (a), g_value_get_variant (b));
        break;
      default:
        if (G_VALUE_TYPE (a) == G_TYPE_STRV)
          ret = _g_strv_equal0 (g_value_get_boxed (a), g_value_get_boxed (b));
        else
          g_critical ("_g_value_equal() does not handle type %s", g_type_name (G_VALUE_TYPE (a)));
        break;
    }
  return ret;
}

/* ------------------------------------------------------------------------
 * Code for interface org.gtk.Private.RemoteVolumeMonitor
 * ------------------------------------------------------------------------
 */

/**
 * SECTION:GVfsRemoteVolumeMonitor
 * @title: GVfsRemoteVolumeMonitor
 * @short_description: Generated C code for the org.gtk.Private.RemoteVolumeMonitor D-Bus interface
 *
 * This section contains code for working with the <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link> D-Bus interface in C.
 */

/* ---- Introspection data for org.gtk.Private.RemoteVolumeMonitor ---- */

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_is_supported_OUT_ARG_is_supported =
{
  {
    -1,
    (gchar *) "is_supported",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_is_supported_OUT_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_is_supported_OUT_ARG_is_supported,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_is_supported =
{
  {
    -1,
    (gchar *) "IsSupported",
    NULL,
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_is_supported_OUT_ARG_pointers,
    NULL
  },
  "handle-is-supported",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_list_OUT_ARG_drives =
{
  {
    -1,
    (gchar *) "drives",
    (gchar *) "a(ssssbbbbbbbbuasa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_list_OUT_ARG_volumes =
{
  {
    -1,
    (gchar *) "volumes",
    (gchar *) "a(ssssssbbssa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_list_OUT_ARG_mounts =
{
  {
    -1,
    (gchar *) "mounts",
    (gchar *) "a(ssssssbsassa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_list_OUT_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_list_OUT_ARG_drives,
  &_gvfs_remote_volume_monitor_method_info_list_OUT_ARG_volumes,
  &_gvfs_remote_volume_monitor_method_info_list_OUT_ARG_mounts,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_list =
{
  {
    -1,
    (gchar *) "List",
    NULL,
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_list_OUT_ARG_pointers,
    NULL
  },
  "handle-list",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_cancel_operation_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_cancel_operation_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_cancel_operation_IN_ARG_cancellation_id,
  NULL
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_cancel_operation_OUT_ARG_was_cancelled =
{
  {
    -1,
    (gchar *) "was_cancelled",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_cancel_operation_OUT_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_cancel_operation_OUT_ARG_was_cancelled,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_cancel_operation =
{
  {
    -1,
    (gchar *) "CancelOperation",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_cancel_operation_IN_ARG_pointers,
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_cancel_operation_OUT_ARG_pointers,
    NULL
  },
  "handle-cancel-operation",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_unmount_flags =
{
  {
    -1,
    (gchar *) "unmount_flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_mount_op_id =
{
  {
    -1,
    (gchar *) "mount_op_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_id,
  &_gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_cancellation_id,
  &_gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_unmount_flags,
  &_gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_mount_op_id,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_mount_unmount =
{
  {
    -1,
    (gchar *) "MountUnmount",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_mount_unmount_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-mount-unmount",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_mount_flags =
{
  {
    -1,
    (gchar *) "mount_flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_mount_op_id =
{
  {
    -1,
    (gchar *) "mount_op_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_id,
  &_gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_cancellation_id,
  &_gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_mount_flags,
  &_gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_mount_op_id,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_volume_mount =
{
  {
    -1,
    (gchar *) "VolumeMount",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_volume_mount_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-volume-mount",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_unmount_flags =
{
  {
    -1,
    (gchar *) "unmount_flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_mount_op_id =
{
  {
    -1,
    (gchar *) "mount_op_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_id,
  &_gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_cancellation_id,
  &_gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_unmount_flags,
  &_gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_mount_op_id,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_drive_eject =
{
  {
    -1,
    (gchar *) "DriveEject",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_drive_eject_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-drive-eject",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_poll_for_media_IN_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_poll_for_media_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_drive_poll_for_media_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_drive_poll_for_media_IN_ARG_id,
  &_gvfs_remote_volume_monitor_method_info_drive_poll_for_media_IN_ARG_cancellation_id,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_drive_poll_for_media =
{
  {
    -1,
    (gchar *) "DrivePollForMedia",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_drive_poll_for_media_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-drive-poll-for-media",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_flags =
{
  {
    -1,
    (gchar *) "flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_mount_op_id =
{
  {
    -1,
    (gchar *) "mount_op_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_id,
  &_gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_cancellation_id,
  &_gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_flags,
  &_gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_mount_op_id,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_drive_start =
{
  {
    -1,
    (gchar *) "DriveStart",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_drive_start_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-drive-start",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_cancellation_id =
{
  {
    -1,
    (gchar *) "cancellation_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_unmount_flags =
{
  {
    -1,
    (gchar *) "unmount_flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_mount_op_id =
{
  {
    -1,
    (gchar *) "mount_op_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_id,
  &_gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_cancellation_id,
  &_gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_unmount_flags,
  &_gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_mount_op_id,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_drive_stop =
{
  {
    -1,
    (gchar *) "DriveStop",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_drive_stop_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-drive-stop",
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_mount_op_id =
{
  {
    -1,
    (gchar *) "mount_op_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_result =
{
  {
    -1,
    (gchar *) "result",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_user_name =
{
  {
    -1,
    (gchar *) "user_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_domain =
{
  {
    -1,
    (gchar *) "domain",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_encoded_password =
{
  {
    -1,
    (gchar *) "encoded_password",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_password_save =
{
  {
    -1,
    (gchar *) "password_save",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_choice =
{
  {
    -1,
    (gchar *) "choice",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_anonymous =
{
  {
    -1,
    (gchar *) "anonymous",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_mount_op_id,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_result,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_user_name,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_domain,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_encoded_password,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_password_save,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_choice,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_anonymous,
  NULL
};

static const _ExtendedGDBusMethodInfo _gvfs_remote_volume_monitor_method_info_mount_op_reply =
{
  {
    -1,
    (gchar *) "MountOpReply",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_method_info_mount_op_reply_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-mount-op-reply",
  FALSE
};

static const _ExtendedGDBusMethodInfo * const _gvfs_remote_volume_monitor_method_info_pointers[] =
{
  &_gvfs_remote_volume_monitor_method_info_is_supported,
  &_gvfs_remote_volume_monitor_method_info_list,
  &_gvfs_remote_volume_monitor_method_info_cancel_operation,
  &_gvfs_remote_volume_monitor_method_info_mount_unmount,
  &_gvfs_remote_volume_monitor_method_info_volume_mount,
  &_gvfs_remote_volume_monitor_method_info_drive_eject,
  &_gvfs_remote_volume_monitor_method_info_drive_poll_for_media,
  &_gvfs_remote_volume_monitor_method_info_drive_start,
  &_gvfs_remote_volume_monitor_method_info_drive_stop,
  &_gvfs_remote_volume_monitor_method_info_mount_op_reply,
  NULL
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_drive =
{
  {
    -1,
    (gchar *) "drive",
    (gchar *) "(ssssbbbbbbbbuasa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_drive,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_drive_changed =
{
  {
    -1,
    (gchar *) "DriveChanged",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_drive_changed_ARG_pointers,
    NULL
  },
  "drive-changed"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_drive =
{
  {
    -1,
    (gchar *) "drive",
    (gchar *) "(ssssbbbbbbbbuasa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_drive,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_drive_connected =
{
  {
    -1,
    (gchar *) "DriveConnected",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_drive_connected_ARG_pointers,
    NULL
  },
  "drive-connected"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_drive =
{
  {
    -1,
    (gchar *) "drive",
    (gchar *) "(ssssbbbbbbbbuasa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_drive,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_drive_disconnected =
{
  {
    -1,
    (gchar *) "DriveDisconnected",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_drive_disconnected_ARG_pointers,
    NULL
  },
  "drive-disconnected"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_drive =
{
  {
    -1,
    (gchar *) "drive",
    (gchar *) "(ssssbbbbbbbbuasa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_drive,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_drive_eject_button =
{
  {
    -1,
    (gchar *) "DriveEjectButton",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_drive_eject_button_ARG_pointers,
    NULL
  },
  "drive-eject-button"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_drive =
{
  {
    -1,
    (gchar *) "drive",
    (gchar *) "(ssssbbbbbbbbuasa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_drive,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_drive_stop_button =
{
  {
    -1,
    (gchar *) "DriveStopButton",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_drive_stop_button_ARG_pointers,
    NULL
  },
  "drive-stop-button"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_volume =
{
  {
    -1,
    (gchar *) "volume",
    (gchar *) "(ssssssbbssa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_volume,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_volume_changed =
{
  {
    -1,
    (gchar *) "VolumeChanged",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_volume_changed_ARG_pointers,
    NULL
  },
  "volume-changed"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_added_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_added_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_added_ARG_volume =
{
  {
    -1,
    (gchar *) "volume",
    (gchar *) "(ssssssbbssa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_volume_added_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_volume_added_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_volume_added_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_volume_added_ARG_volume,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_volume_added =
{
  {
    -1,
    (gchar *) "VolumeAdded",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_volume_added_ARG_pointers,
    NULL
  },
  "volume-added"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_volume =
{
  {
    -1,
    (gchar *) "volume",
    (gchar *) "(ssssssbbssa{ss}sa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_volume,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_volume_removed =
{
  {
    -1,
    (gchar *) "VolumeRemoved",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_volume_removed_ARG_pointers,
    NULL
  },
  "volume-removed"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_mount =
{
  {
    -1,
    (gchar *) "mount",
    (gchar *) "(ssssssbsassa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_mount,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_changed =
{
  {
    -1,
    (gchar *) "MountChanged",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_changed_ARG_pointers,
    NULL
  },
  "mount-changed"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_added_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_added_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_added_ARG_mount =
{
  {
    -1,
    (gchar *) "mount",
    (gchar *) "(ssssssbsassa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_added_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_added_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_added_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_added_ARG_mount,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_added =
{
  {
    -1,
    (gchar *) "MountAdded",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_added_ARG_pointers,
    NULL
  },
  "mount-added"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_mount =
{
  {
    -1,
    (gchar *) "mount",
    (gchar *) "(ssssssbsassa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_mount,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_pre_unmount =
{
  {
    -1,
    (gchar *) "MountPreUnmount",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_pre_unmount_ARG_pointers,
    NULL
  },
  "mount-pre-unmount"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_mount =
{
  {
    -1,
    (gchar *) "mount",
    (gchar *) "(ssssssbsassa{sv})",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_mount,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_removed =
{
  {
    -1,
    (gchar *) "MountRemoved",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_removed_ARG_pointers,
    NULL
  },
  "mount-removed"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_message_to_show =
{
  {
    -1,
    (gchar *) "message_to_show",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_default_user =
{
  {
    -1,
    (gchar *) "default_user",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_default_domain =
{
  {
    -1,
    (gchar *) "default_domain",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_flags =
{
  {
    -1,
    (gchar *) "flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_message_to_show,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_default_user,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_default_domain,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_flags,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_password =
{
  {
    -1,
    (gchar *) "MountOpAskPassword",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password_ARG_pointers,
    NULL
  },
  "mount-op-ask-password"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_message_to_show =
{
  {
    -1,
    (gchar *) "message_to_show",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_choices =
{
  {
    -1,
    (gchar *) "choices",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_message_to_show,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_choices,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_op_ask_question =
{
  {
    -1,
    (gchar *) "MountOpAskQuestion",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_question_ARG_pointers,
    NULL
  },
  "mount-op-ask-question"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_message_to_show =
{
  {
    -1,
    (gchar *) "message_to_show",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_pid =
{
  {
    -1,
    (gchar *) "pid",
    (gchar *) "ai",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_choices =
{
  {
    -1,
    (gchar *) "choices",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_message_to_show,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_pid,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_choices,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_processes =
{
  {
    -1,
    (gchar *) "MountOpShowProcesses",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes_ARG_pointers,
    NULL
  },
  "mount-op-show-processes"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_message_to_show =
{
  {
    -1,
    (gchar *) "message_to_show",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_time_left =
{
  {
    -1,
    (gchar *) "time_left",
    (gchar *) "x",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_bytes_left =
{
  {
    -1,
    (gchar *) "bytes_left",
    (gchar *) "x",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_id,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_message_to_show,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_time_left,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_bytes_left,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress =
{
  {
    -1,
    (gchar *) "MountOpShowUnmountProgress",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress_ARG_pointers,
    NULL
  },
  "mount-op-show-unmount-progress"
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_aborted_ARG_dbus_name =
{
  {
    -1,
    (gchar *) "dbus_name",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gvfs_remote_volume_monitor_signal_info_mount_op_aborted_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gvfs_remote_volume_monitor_signal_info_mount_op_aborted_ARG_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_mount_op_aborted_ARG_dbus_name,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_aborted_ARG_id,
  NULL
};

static const _ExtendedGDBusSignalInfo _gvfs_remote_volume_monitor_signal_info_mount_op_aborted =
{
  {
    -1,
    (gchar *) "MountOpAborted",
    (GDBusArgInfo **) &_gvfs_remote_volume_monitor_signal_info_mount_op_aborted_ARG_pointers,
    NULL
  },
  "mount-op-aborted"
};

static const _ExtendedGDBusSignalInfo * const _gvfs_remote_volume_monitor_signal_info_pointers[] =
{
  &_gvfs_remote_volume_monitor_signal_info_drive_changed,
  &_gvfs_remote_volume_monitor_signal_info_drive_connected,
  &_gvfs_remote_volume_monitor_signal_info_drive_disconnected,
  &_gvfs_remote_volume_monitor_signal_info_drive_eject_button,
  &_gvfs_remote_volume_monitor_signal_info_drive_stop_button,
  &_gvfs_remote_volume_monitor_signal_info_volume_changed,
  &_gvfs_remote_volume_monitor_signal_info_volume_added,
  &_gvfs_remote_volume_monitor_signal_info_volume_removed,
  &_gvfs_remote_volume_monitor_signal_info_mount_changed,
  &_gvfs_remote_volume_monitor_signal_info_mount_added,
  &_gvfs_remote_volume_monitor_signal_info_mount_pre_unmount,
  &_gvfs_remote_volume_monitor_signal_info_mount_removed,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_password,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_ask_question,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_processes,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_show_unmount_progress,
  &_gvfs_remote_volume_monitor_signal_info_mount_op_aborted,
  NULL
};

static const _ExtendedGDBusInterfaceInfo _gvfs_remote_volume_monitor_interface_info =
{
  {
    -1,
    (gchar *) "org.gtk.Private.RemoteVolumeMonitor",
    (GDBusMethodInfo **) &_gvfs_remote_volume_monitor_method_info_pointers,
    (GDBusSignalInfo **) &_gvfs_remote_volume_monitor_signal_info_pointers,
    NULL,
    NULL
  },
  "remote-volume-monitor",
};


/**
 * gvfs_remote_volume_monitor_interface_info:
 *
 * Gets a machine-readable description of the <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link> D-Bus interface.
 *
 * Returns: (transfer none): A #GDBusInterfaceInfo. Do not free.
 */
GDBusInterfaceInfo *
gvfs_remote_volume_monitor_interface_info (void)
{
  return (GDBusInterfaceInfo *) &_gvfs_remote_volume_monitor_interface_info.parent_struct;
}

/**
 * gvfs_remote_volume_monitor_override_properties:
 * @klass: The class structure for a #GObject<!-- -->-derived class.
 * @property_id_begin: The property id to assign to the first overridden property.
 *
 * Overrides all #GObject properties in the #GVfsRemoteVolumeMonitor interface for a concrete class.
 * The properties are overridden in the order they are defined.
 *
 * Returns: The last property id.
 */
guint
gvfs_remote_volume_monitor_override_properties (GObjectClass *klass, guint property_id_begin)
{
  return property_id_begin - 1;
}



/**
 * GVfsRemoteVolumeMonitor:
 *
 * Abstract interface type for the D-Bus interface <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link>.
 */

/**
 * GVfsRemoteVolumeMonitorIface:
 * @parent_iface: The parent interface.
 * @handle_cancel_operation: Handler for the #GVfsRemoteVolumeMonitor::handle-cancel-operation signal.
 * @handle_drive_eject: Handler for the #GVfsRemoteVolumeMonitor::handle-drive-eject signal.
 * @handle_drive_poll_for_media: Handler for the #GVfsRemoteVolumeMonitor::handle-drive-poll-for-media signal.
 * @handle_drive_start: Handler for the #GVfsRemoteVolumeMonitor::handle-drive-start signal.
 * @handle_drive_stop: Handler for the #GVfsRemoteVolumeMonitor::handle-drive-stop signal.
 * @handle_is_supported: Handler for the #GVfsRemoteVolumeMonitor::handle-is-supported signal.
 * @handle_list: Handler for the #GVfsRemoteVolumeMonitor::handle-list signal.
 * @handle_mount_op_reply: Handler for the #GVfsRemoteVolumeMonitor::handle-mount-op-reply signal.
 * @handle_mount_unmount: Handler for the #GVfsRemoteVolumeMonitor::handle-mount-unmount signal.
 * @handle_volume_mount: Handler for the #GVfsRemoteVolumeMonitor::handle-volume-mount signal.
 * @drive_changed: Handler for the #GVfsRemoteVolumeMonitor::drive-changed signal.
 * @drive_connected: Handler for the #GVfsRemoteVolumeMonitor::drive-connected signal.
 * @drive_disconnected: Handler for the #GVfsRemoteVolumeMonitor::drive-disconnected signal.
 * @drive_eject_button: Handler for the #GVfsRemoteVolumeMonitor::drive-eject-button signal.
 * @drive_stop_button: Handler for the #GVfsRemoteVolumeMonitor::drive-stop-button signal.
 * @mount_added: Handler for the #GVfsRemoteVolumeMonitor::mount-added signal.
 * @mount_changed: Handler for the #GVfsRemoteVolumeMonitor::mount-changed signal.
 * @mount_op_aborted: Handler for the #GVfsRemoteVolumeMonitor::mount-op-aborted signal.
 * @mount_op_ask_password: Handler for the #GVfsRemoteVolumeMonitor::mount-op-ask-password signal.
 * @mount_op_ask_question: Handler for the #GVfsRemoteVolumeMonitor::mount-op-ask-question signal.
 * @mount_op_show_processes: Handler for the #GVfsRemoteVolumeMonitor::mount-op-show-processes signal.
 * @mount_op_show_unmount_progress: Handler for the #GVfsRemoteVolumeMonitor::mount-op-show-unmount-progress signal.
 * @mount_pre_unmount: Handler for the #GVfsRemoteVolumeMonitor::mount-pre-unmount signal.
 * @mount_removed: Handler for the #GVfsRemoteVolumeMonitor::mount-removed signal.
 * @volume_added: Handler for the #GVfsRemoteVolumeMonitor::volume-added signal.
 * @volume_changed: Handler for the #GVfsRemoteVolumeMonitor::volume-changed signal.
 * @volume_removed: Handler for the #GVfsRemoteVolumeMonitor::volume-removed signal.
 *
 * Virtual table for the D-Bus interface <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link>.
 */

typedef GVfsRemoteVolumeMonitorIface GVfsRemoteVolumeMonitorInterface;
G_DEFINE_INTERFACE (GVfsRemoteVolumeMonitor, gvfs_remote_volume_monitor, G_TYPE_OBJECT);

static void
gvfs_remote_volume_monitor_default_init (GVfsRemoteVolumeMonitorIface *iface)
{
  /* GObject signals for incoming D-Bus method calls: */
  /**
   * GVfsRemoteVolumeMonitor::handle-is-supported:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.IsSupported">IsSupported()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_is_supported() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-is-supported",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_is_supported),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GVfsRemoteVolumeMonitor::handle-list:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.List">List()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_list() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-list",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_list),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GVfsRemoteVolumeMonitor::handle-cancel-operation:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_cancellation_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.CancelOperation">CancelOperation()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_cancel_operation() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-cancel-operation",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_cancel_operation),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-mount-unmount:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_id: Argument passed by remote caller.
   * @arg_cancellation_id: Argument passed by remote caller.
   * @arg_unmount_flags: Argument passed by remote caller.
   * @arg_mount_op_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountUnmount">MountUnmount()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_mount_unmount() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-mount-unmount",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_mount_unmount),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    5,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-volume-mount:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_id: Argument passed by remote caller.
   * @arg_cancellation_id: Argument passed by remote caller.
   * @arg_mount_flags: Argument passed by remote caller.
   * @arg_mount_op_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.VolumeMount">VolumeMount()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_volume_mount() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-volume-mount",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_volume_mount),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    5,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-drive-eject:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_id: Argument passed by remote caller.
   * @arg_cancellation_id: Argument passed by remote caller.
   * @arg_unmount_flags: Argument passed by remote caller.
   * @arg_mount_op_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveEject">DriveEject()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_drive_eject() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-drive-eject",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_drive_eject),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    5,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-drive-poll-for-media:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_id: Argument passed by remote caller.
   * @arg_cancellation_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DrivePollForMedia">DrivePollForMedia()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_drive_poll_for_media() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-drive-poll-for-media",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_drive_poll_for_media),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-drive-start:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_id: Argument passed by remote caller.
   * @arg_cancellation_id: Argument passed by remote caller.
   * @arg_flags: Argument passed by remote caller.
   * @arg_mount_op_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStart">DriveStart()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_drive_start() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-drive-start",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_drive_start),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    5,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-drive-stop:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_id: Argument passed by remote caller.
   * @arg_cancellation_id: Argument passed by remote caller.
   * @arg_unmount_flags: Argument passed by remote caller.
   * @arg_mount_op_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStop">DriveStop()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_drive_stop() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-drive-stop",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_drive_stop),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    5,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING);

  /**
   * GVfsRemoteVolumeMonitor::handle-mount-op-reply:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_mount_op_id: Argument passed by remote caller.
   * @arg_result: Argument passed by remote caller.
   * @arg_user_name: Argument passed by remote caller.
   * @arg_domain: Argument passed by remote caller.
   * @arg_encoded_password: Argument passed by remote caller.
   * @arg_password_save: Argument passed by remote caller.
   * @arg_choice: Argument passed by remote caller.
   * @arg_anonymous: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountOpReply">MountOpReply()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gvfs_remote_volume_monitor_complete_mount_op_reply() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-mount-op-reply",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, handle_mount_op_reply),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    9,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_BOOLEAN);

  /* GObject signals for received D-Bus signals: */
  /**
   * GVfsRemoteVolumeMonitor::drive-changed:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_drive: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveChanged">"DriveChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("drive-changed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, drive_changed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::drive-connected:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_drive: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveConnected">"DriveConnected"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("drive-connected",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, drive_connected),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::drive-disconnected:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_drive: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveDisconnected">"DriveDisconnected"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("drive-disconnected",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, drive_disconnected),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::drive-eject-button:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_drive: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveEjectButton">"DriveEjectButton"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("drive-eject-button",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, drive_eject_button),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::drive-stop-button:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_drive: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveStopButton">"DriveStopButton"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("drive-stop-button",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, drive_stop_button),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::volume-changed:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_volume: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.VolumeChanged">"VolumeChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("volume-changed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, volume_changed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::volume-added:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_volume: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.VolumeAdded">"VolumeAdded"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("volume-added",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, volume_added),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::volume-removed:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_volume: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.VolumeRemoved">"VolumeRemoved"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("volume-removed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, volume_removed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::mount-changed:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_mount: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountChanged">"MountChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-changed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_changed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::mount-added:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_mount: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountAdded">"MountAdded"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-added",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_added),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::mount-pre-unmount:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_mount: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountPreUnmount">"MountPreUnmount"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-pre-unmount",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_pre_unmount),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::mount-removed:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_mount: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountRemoved">"MountRemoved"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-removed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_removed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT);

  /**
   * GVfsRemoteVolumeMonitor::mount-op-ask-password:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_message_to_show: Argument.
   * @arg_default_user: Argument.
   * @arg_default_domain: Argument.
   * @arg_flags: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpAskPassword">"MountOpAskPassword"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-op-ask-password",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_op_ask_password),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    6, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);

  /**
   * GVfsRemoteVolumeMonitor::mount-op-ask-question:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_message_to_show: Argument.
   * @arg_choices: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpAskQuestion">"MountOpAskQuestion"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-op-ask-question",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_op_ask_question),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRV);

  /**
   * GVfsRemoteVolumeMonitor::mount-op-show-processes:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_message_to_show: Argument.
   * @arg_pid: Argument.
   * @arg_choices: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpShowProcesses">"MountOpShowProcesses"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-op-show-processes",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_op_show_processes),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VARIANT, G_TYPE_STRV);

  /**
   * GVfsRemoteVolumeMonitor::mount-op-show-unmount-progress:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   * @arg_message_to_show: Argument.
   * @arg_time_left: Argument.
   * @arg_bytes_left: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpShowUnmountProgress">"MountOpShowUnmountProgress"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-op-show-unmount-progress",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_op_show_unmount_progress),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT64, G_TYPE_INT64);

  /**
   * GVfsRemoteVolumeMonitor::mount-op-aborted:
   * @object: A #GVfsRemoteVolumeMonitor.
   * @arg_dbus_name: Argument.
   * @arg_id: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpAborted">"MountOpAborted"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("mount-op-aborted",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GVfsRemoteVolumeMonitorIface, mount_op_aborted),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    2, G_TYPE_STRING, G_TYPE_STRING);

}

/**
 * gvfs_remote_volume_monitor_emit_drive_changed:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_drive: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveChanged">"DriveChanged"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_drive_changed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  g_signal_emit_by_name (object, "drive-changed", arg_dbus_name, arg_id, arg_drive);
}

/**
 * gvfs_remote_volume_monitor_emit_drive_connected:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_drive: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveConnected">"DriveConnected"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_drive_connected (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  g_signal_emit_by_name (object, "drive-connected", arg_dbus_name, arg_id, arg_drive);
}

/**
 * gvfs_remote_volume_monitor_emit_drive_disconnected:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_drive: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveDisconnected">"DriveDisconnected"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_drive_disconnected (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  g_signal_emit_by_name (object, "drive-disconnected", arg_dbus_name, arg_id, arg_drive);
}

/**
 * gvfs_remote_volume_monitor_emit_drive_eject_button:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_drive: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveEjectButton">"DriveEjectButton"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_drive_eject_button (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  g_signal_emit_by_name (object, "drive-eject-button", arg_dbus_name, arg_id, arg_drive);
}

/**
 * gvfs_remote_volume_monitor_emit_drive_stop_button:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_drive: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.DriveStopButton">"DriveStopButton"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_drive_stop_button (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  g_signal_emit_by_name (object, "drive-stop-button", arg_dbus_name, arg_id, arg_drive);
}

/**
 * gvfs_remote_volume_monitor_emit_volume_changed:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_volume: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.VolumeChanged">"VolumeChanged"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_volume_changed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_volume)
{
  g_signal_emit_by_name (object, "volume-changed", arg_dbus_name, arg_id, arg_volume);
}

/**
 * gvfs_remote_volume_monitor_emit_volume_added:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_volume: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.VolumeAdded">"VolumeAdded"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_volume_added (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_volume)
{
  g_signal_emit_by_name (object, "volume-added", arg_dbus_name, arg_id, arg_volume);
}

/**
 * gvfs_remote_volume_monitor_emit_volume_removed:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_volume: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.VolumeRemoved">"VolumeRemoved"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_volume_removed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_volume)
{
  g_signal_emit_by_name (object, "volume-removed", arg_dbus_name, arg_id, arg_volume);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_changed:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_mount: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountChanged">"MountChanged"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_changed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  g_signal_emit_by_name (object, "mount-changed", arg_dbus_name, arg_id, arg_mount);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_added:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_mount: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountAdded">"MountAdded"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_added (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  g_signal_emit_by_name (object, "mount-added", arg_dbus_name, arg_id, arg_mount);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_pre_unmount:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_mount: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountPreUnmount">"MountPreUnmount"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_pre_unmount (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  g_signal_emit_by_name (object, "mount-pre-unmount", arg_dbus_name, arg_id, arg_mount);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_removed:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_mount: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountRemoved">"MountRemoved"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_removed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  g_signal_emit_by_name (object, "mount-removed", arg_dbus_name, arg_id, arg_mount);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_op_ask_password:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_message_to_show: Argument to pass with the signal.
 * @arg_default_user: Argument to pass with the signal.
 * @arg_default_domain: Argument to pass with the signal.
 * @arg_flags: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpAskPassword">"MountOpAskPassword"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_op_ask_password (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    const gchar *arg_default_user,
    const gchar *arg_default_domain,
    guint arg_flags)
{
  g_signal_emit_by_name (object, "mount-op-ask-password", arg_dbus_name, arg_id, arg_message_to_show, arg_default_user, arg_default_domain, arg_flags);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_op_ask_question:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_message_to_show: Argument to pass with the signal.
 * @arg_choices: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpAskQuestion">"MountOpAskQuestion"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_op_ask_question (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    const gchar *const *arg_choices)
{
  g_signal_emit_by_name (object, "mount-op-ask-question", arg_dbus_name, arg_id, arg_message_to_show, arg_choices);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_op_show_processes:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_message_to_show: Argument to pass with the signal.
 * @arg_pid: Argument to pass with the signal.
 * @arg_choices: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpShowProcesses">"MountOpShowProcesses"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_op_show_processes (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    GVariant *arg_pid,
    const gchar *const *arg_choices)
{
  g_signal_emit_by_name (object, "mount-op-show-processes", arg_dbus_name, arg_id, arg_message_to_show, arg_pid, arg_choices);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_op_show_unmount_progress:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 * @arg_message_to_show: Argument to pass with the signal.
 * @arg_time_left: Argument to pass with the signal.
 * @arg_bytes_left: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpShowUnmountProgress">"MountOpShowUnmountProgress"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_op_show_unmount_progress (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    gint64 arg_time_left,
    gint64 arg_bytes_left)
{
  g_signal_emit_by_name (object, "mount-op-show-unmount-progress", arg_dbus_name, arg_id, arg_message_to_show, arg_time_left, arg_bytes_left);
}

/**
 * gvfs_remote_volume_monitor_emit_mount_op_aborted:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @arg_dbus_name: Argument to pass with the signal.
 * @arg_id: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gtk-Private-RemoteVolumeMonitor.MountOpAborted">"MountOpAborted"</link> D-Bus signal.
 */
void
gvfs_remote_volume_monitor_emit_mount_op_aborted (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id)
{
  g_signal_emit_by_name (object, "mount-op-aborted", arg_dbus_name, arg_id);
}

/**
 * gvfs_remote_volume_monitor_call_is_supported:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.IsSupported">IsSupported()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_is_supported_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_is_supported_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_is_supported (
    GVfsRemoteVolumeMonitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "IsSupported",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_is_supported_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @out_is_supported: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_is_supported().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_is_supported().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_is_supported_finish (
    GVfsRemoteVolumeMonitor *proxy,
    gboolean *out_is_supported,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_is_supported);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_is_supported_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @out_is_supported: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.IsSupported">IsSupported()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_is_supported() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_is_supported_sync (
    GVfsRemoteVolumeMonitor *proxy,
    gboolean *out_is_supported,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "IsSupported",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_is_supported);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_list:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.List">List()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_list_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_list_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_list (
    GVfsRemoteVolumeMonitor *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "List",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_list_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @out_drives: (out): Return location for return parameter or %NULL to ignore.
 * @out_volumes: (out): Return location for return parameter or %NULL to ignore.
 * @out_mounts: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_list().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_list().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_list_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GVariant **out_drives,
    GVariant **out_volumes,
    GVariant **out_mounts,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@a(ssssbbbbbbbbuasa{ss}sa{sv})@a(ssssssbbssa{ss}sa{sv})@a(ssssssbsassa{sv}))",
                 out_drives,
                 out_volumes,
                 out_mounts);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_list_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @out_drives: (out): Return location for return parameter or %NULL to ignore.
 * @out_volumes: (out): Return location for return parameter or %NULL to ignore.
 * @out_mounts: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.List">List()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_list() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_list_sync (
    GVfsRemoteVolumeMonitor *proxy,
    GVariant **out_drives,
    GVariant **out_volumes,
    GVariant **out_mounts,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "List",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@a(ssssbbbbbbbbuasa{ss}sa{sv})@a(ssssssbbssa{ss}sa{sv})@a(ssssssbsassa{sv}))",
                 out_drives,
                 out_volumes,
                 out_mounts);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_cancel_operation:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.CancelOperation">CancelOperation()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_cancel_operation_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_cancel_operation_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_cancel_operation (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_cancellation_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "CancelOperation",
    g_variant_new ("(s)",
                   arg_cancellation_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_cancel_operation_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @out_was_cancelled: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_cancel_operation().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_cancel_operation().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_cancel_operation_finish (
    GVfsRemoteVolumeMonitor *proxy,
    gboolean *out_was_cancelled,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_was_cancelled);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_cancel_operation_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @out_was_cancelled: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.CancelOperation">CancelOperation()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_cancel_operation() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_cancel_operation_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_cancellation_id,
    gboolean *out_was_cancelled,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "CancelOperation",
    g_variant_new ("(s)",
                   arg_cancellation_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_was_cancelled);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_mount_unmount:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_unmount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountUnmount">MountUnmount()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_mount_unmount_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_mount_unmount_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_mount_unmount (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_unmount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "MountUnmount",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_unmount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_mount_unmount_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_mount_unmount().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_mount_unmount().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_mount_unmount_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_mount_unmount_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_unmount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountUnmount">MountUnmount()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_mount_unmount() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_mount_unmount_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_unmount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "MountUnmount",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_unmount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_volume_mount:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_mount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.VolumeMount">VolumeMount()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_volume_mount_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_volume_mount_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_volume_mount (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_mount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "VolumeMount",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_mount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_volume_mount_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_volume_mount().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_volume_mount().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_volume_mount_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_volume_mount_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_mount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.VolumeMount">VolumeMount()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_volume_mount() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_volume_mount_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_mount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "VolumeMount",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_mount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_eject:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_unmount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveEject">DriveEject()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_drive_eject_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_drive_eject_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_drive_eject (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_unmount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "DriveEject",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_unmount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_drive_eject_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_drive_eject().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_drive_eject().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_eject_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_eject_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_unmount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveEject">DriveEject()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_drive_eject() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_eject_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_unmount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "DriveEject",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_unmount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_poll_for_media:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DrivePollForMedia">DrivePollForMedia()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_drive_poll_for_media_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_drive_poll_for_media_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_drive_poll_for_media (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "DrivePollForMedia",
    g_variant_new ("(ss)",
                   arg_id,
                   arg_cancellation_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_drive_poll_for_media_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_drive_poll_for_media().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_drive_poll_for_media().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_poll_for_media_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_poll_for_media_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DrivePollForMedia">DrivePollForMedia()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_drive_poll_for_media() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_poll_for_media_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "DrivePollForMedia",
    g_variant_new ("(ss)",
                   arg_id,
                   arg_cancellation_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_start:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStart">DriveStart()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_drive_start_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_drive_start_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_drive_start (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "DriveStart",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_drive_start_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_drive_start().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_drive_start().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_start_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_start_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStart">DriveStart()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_drive_start() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_start_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "DriveStart",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_stop:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_unmount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStop">DriveStop()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_drive_stop_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_drive_stop_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_drive_stop (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_unmount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "DriveStop",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_unmount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_drive_stop_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_drive_stop().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_drive_stop().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_stop_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_drive_stop_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_id: Argument to pass with the method invocation.
 * @arg_cancellation_id: Argument to pass with the method invocation.
 * @arg_unmount_flags: Argument to pass with the method invocation.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStop">DriveStop()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_drive_stop() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_drive_stop_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_id,
    const gchar *arg_cancellation_id,
    guint arg_unmount_flags,
    const gchar *arg_mount_op_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "DriveStop",
    g_variant_new ("(ssus)",
                   arg_id,
                   arg_cancellation_id,
                   arg_unmount_flags,
                   arg_mount_op_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_mount_op_reply:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @arg_result: Argument to pass with the method invocation.
 * @arg_user_name: Argument to pass with the method invocation.
 * @arg_domain: Argument to pass with the method invocation.
 * @arg_encoded_password: Argument to pass with the method invocation.
 * @arg_password_save: Argument to pass with the method invocation.
 * @arg_choice: Argument to pass with the method invocation.
 * @arg_anonymous: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountOpReply">MountOpReply()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_call_mount_op_reply_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_call_mount_op_reply_sync() for the synchronous, blocking version of this method.
 */
void
gvfs_remote_volume_monitor_call_mount_op_reply (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_mount_op_id,
    gint arg_result,
    const gchar *arg_user_name,
    const gchar *arg_domain,
    const gchar *arg_encoded_password,
    gint arg_password_save,
    gint arg_choice,
    gboolean arg_anonymous,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "MountOpReply",
    g_variant_new ("(sisssiib)",
                   arg_mount_op_id,
                   arg_result,
                   arg_user_name,
                   arg_domain,
                   arg_encoded_password,
                   arg_password_save,
                   arg_choice,
                   arg_anonymous),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gvfs_remote_volume_monitor_call_mount_op_reply_finish:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_call_mount_op_reply().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_call_mount_op_reply().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_mount_op_reply_finish (
    GVfsRemoteVolumeMonitor *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_call_mount_op_reply_sync:
 * @proxy: A #GVfsRemoteVolumeMonitorProxy.
 * @arg_mount_op_id: Argument to pass with the method invocation.
 * @arg_result: Argument to pass with the method invocation.
 * @arg_user_name: Argument to pass with the method invocation.
 * @arg_domain: Argument to pass with the method invocation.
 * @arg_encoded_password: Argument to pass with the method invocation.
 * @arg_password_save: Argument to pass with the method invocation.
 * @arg_choice: Argument to pass with the method invocation.
 * @arg_anonymous: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountOpReply">MountOpReply()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_call_mount_op_reply() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gvfs_remote_volume_monitor_call_mount_op_reply_sync (
    GVfsRemoteVolumeMonitor *proxy,
    const gchar *arg_mount_op_id,
    gint arg_result,
    const gchar *arg_user_name,
    const gchar *arg_domain,
    const gchar *arg_encoded_password,
    gint arg_password_save,
    gint arg_choice,
    gboolean arg_anonymous,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "MountOpReply",
    g_variant_new ("(sisssiib)",
                   arg_mount_op_id,
                   arg_result,
                   arg_user_name,
                   arg_domain,
                   arg_encoded_password,
                   arg_password_save,
                   arg_choice,
                   arg_anonymous),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gvfs_remote_volume_monitor_complete_is_supported:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @is_supported: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.IsSupported">IsSupported()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_is_supported (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation,
    gboolean is_supported)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   is_supported));
}

/**
 * gvfs_remote_volume_monitor_complete_list:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @drives: Parameter to return.
 * @volumes: Parameter to return.
 * @mounts: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.List">List()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_list (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation,
    GVariant *drives,
    GVariant *volumes,
    GVariant *mounts)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(@a(ssssbbbbbbbbuasa{ss}sa{sv})@a(ssssssbbssa{ss}sa{sv})@a(ssssssbsassa{sv}))",
                   drives,
                   volumes,
                   mounts));
}

/**
 * gvfs_remote_volume_monitor_complete_cancel_operation:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @was_cancelled: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.CancelOperation">CancelOperation()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_cancel_operation (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation,
    gboolean was_cancelled)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   was_cancelled));
}

/**
 * gvfs_remote_volume_monitor_complete_mount_unmount:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountUnmount">MountUnmount()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_mount_unmount (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gvfs_remote_volume_monitor_complete_volume_mount:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.VolumeMount">VolumeMount()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_volume_mount (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gvfs_remote_volume_monitor_complete_drive_eject:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveEject">DriveEject()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_drive_eject (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gvfs_remote_volume_monitor_complete_drive_poll_for_media:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DrivePollForMedia">DrivePollForMedia()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_drive_poll_for_media (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gvfs_remote_volume_monitor_complete_drive_start:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStart">DriveStart()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_drive_start (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gvfs_remote_volume_monitor_complete_drive_stop:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.DriveStop">DriveStop()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_drive_stop (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gvfs_remote_volume_monitor_complete_mount_op_reply:
 * @object: A #GVfsRemoteVolumeMonitor.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gtk-Private-RemoteVolumeMonitor.MountOpReply">MountOpReply()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gvfs_remote_volume_monitor_complete_mount_op_reply (
    GVfsRemoteVolumeMonitor *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/* ------------------------------------------------------------------------ */

/**
 * GVfsRemoteVolumeMonitorProxy:
 *
 * The #GVfsRemoteVolumeMonitorProxy structure contains only private data and should only be accessed using the provided API.
 */

/**
 * GVfsRemoteVolumeMonitorProxyClass:
 * @parent_class: The parent class.
 *
 * Class structure for #GVfsRemoteVolumeMonitorProxy.
 */

struct _GVfsRemoteVolumeMonitorProxyPrivate
{
  GData *qdata;
};

static void gvfs_remote_volume_monitor_proxy_iface_init (GVfsRemoteVolumeMonitorIface *iface);

#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (GVfsRemoteVolumeMonitorProxy, gvfs_remote_volume_monitor_proxy, G_TYPE_DBUS_PROXY,
                         G_ADD_PRIVATE (GVfsRemoteVolumeMonitorProxy)
                         G_IMPLEMENT_INTERFACE (GVFS_TYPE_REMOTE_VOLUME_MONITOR, gvfs_remote_volume_monitor_proxy_iface_init));

#else
G_DEFINE_TYPE_WITH_CODE (GVfsRemoteVolumeMonitorProxy, gvfs_remote_volume_monitor_proxy, G_TYPE_DBUS_PROXY,
                         G_IMPLEMENT_INTERFACE (GVFS_TYPE_REMOTE_VOLUME_MONITOR, gvfs_remote_volume_monitor_proxy_iface_init));

#endif
static void
gvfs_remote_volume_monitor_proxy_finalize (GObject *object)
{
  GVfsRemoteVolumeMonitorProxy *proxy = GVFS_REMOTE_VOLUME_MONITOR_PROXY (object);
  g_datalist_clear (&proxy->priv->qdata);
  G_OBJECT_CLASS (gvfs_remote_volume_monitor_proxy_parent_class)->finalize (object);
}

static void
gvfs_remote_volume_monitor_proxy_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
}

static void
gvfs_remote_volume_monitor_proxy_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
}

static void
gvfs_remote_volume_monitor_proxy_g_signal (GDBusProxy *proxy,
  const gchar *sender_name G_GNUC_UNUSED,
  const gchar *signal_name,
  GVariant *parameters)
{
  _ExtendedGDBusSignalInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  guint num_params;
  guint n;
  guint signal_id;
  info = (_ExtendedGDBusSignalInfo *) g_dbus_interface_info_lookup_signal ((GDBusInterfaceInfo *) &_gvfs_remote_volume_monitor_interface_info.parent_struct, signal_name);
  if (info == NULL)
    return;
  num_params = g_variant_n_children (parameters);
  paramv = g_new0 (GValue, num_params + 1);
  g_value_init (&paramv[0], GVFS_TYPE_REMOTE_VOLUME_MONITOR);
  g_value_set_object (&paramv[0], proxy);
  g_variant_iter_init (&iter, parameters);
  n = 1;
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.args[n - 1];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, GVFS_TYPE_REMOTE_VOLUME_MONITOR);
  g_signal_emitv (paramv, signal_id, 0, NULL);
  for (n = 0; n < num_params + 1; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static void
gvfs_remote_volume_monitor_proxy_g_properties_changed (GDBusProxy *_proxy,
  GVariant *changed_properties,
  const gchar *const *invalidated_properties)
{
  GVfsRemoteVolumeMonitorProxy *proxy = GVFS_REMOTE_VOLUME_MONITOR_PROXY (_proxy);
  guint n;
  const gchar *key;
  GVariantIter *iter;
  _ExtendedGDBusPropertyInfo *info;
  g_variant_get (changed_properties, "a{sv}", &iter);
  while (g_variant_iter_next (iter, "{&sv}", &key, NULL))
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gvfs_remote_volume_monitor_interface_info.parent_struct, key);
      g_datalist_remove_data (&proxy->priv->qdata, key);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
  g_variant_iter_free (iter);
  for (n = 0; invalidated_properties[n] != NULL; n++)
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gvfs_remote_volume_monitor_interface_info.parent_struct, invalidated_properties[n]);
      g_datalist_remove_data (&proxy->priv->qdata, invalidated_properties[n]);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
}

static void
gvfs_remote_volume_monitor_proxy_init (GVfsRemoteVolumeMonitorProxy *proxy)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  proxy->priv = gvfs_remote_volume_monitor_proxy_get_instance_private (proxy);
#else
  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy, GVFS_TYPE_REMOTE_VOLUME_MONITOR_PROXY, GVfsRemoteVolumeMonitorProxyPrivate);
#endif

  g_dbus_proxy_set_interface_info (G_DBUS_PROXY (proxy), gvfs_remote_volume_monitor_interface_info ());
}

static void
gvfs_remote_volume_monitor_proxy_class_init (GVfsRemoteVolumeMonitorProxyClass *klass)
{
  GObjectClass *gobject_class;
  GDBusProxyClass *proxy_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize     = gvfs_remote_volume_monitor_proxy_finalize;
  gobject_class->get_property = gvfs_remote_volume_monitor_proxy_get_property;
  gobject_class->set_property = gvfs_remote_volume_monitor_proxy_set_property;

  proxy_class = G_DBUS_PROXY_CLASS (klass);
  proxy_class->g_signal = gvfs_remote_volume_monitor_proxy_g_signal;
  proxy_class->g_properties_changed = gvfs_remote_volume_monitor_proxy_g_properties_changed;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (GVfsRemoteVolumeMonitorProxyPrivate));
#endif
}

static void
gvfs_remote_volume_monitor_proxy_iface_init (GVfsRemoteVolumeMonitorIface *iface)
{
}

/**
 * gvfs_remote_volume_monitor_proxy_new:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (allow-none): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link>. See g_dbus_proxy_new() for more details.
 *
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_proxy_new_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_proxy_new_sync() for the synchronous, blocking version of this constructor.
 */
void
gvfs_remote_volume_monitor_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (GVFS_TYPE_REMOTE_VOLUME_MONITOR_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.gtk.Private.RemoteVolumeMonitor", NULL);
}

/**
 * gvfs_remote_volume_monitor_proxy_new_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_proxy_new().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_proxy_new().
 *
 * Returns: (transfer full) (type GVfsRemoteVolumeMonitorProxy): The constructed proxy object or %NULL if @error is set.
 */
GVfsRemoteVolumeMonitor *
gvfs_remote_volume_monitor_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return GVFS_REMOTE_VOLUME_MONITOR (ret);
  else
    return NULL;
}

/**
 * gvfs_remote_volume_monitor_proxy_new_sync:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (allow-none): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Synchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link>. See g_dbus_proxy_new_sync() for more details.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_proxy_new() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type GVfsRemoteVolumeMonitorProxy): The constructed proxy object or %NULL if @error is set.
 */
GVfsRemoteVolumeMonitor *
gvfs_remote_volume_monitor_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (GVFS_TYPE_REMOTE_VOLUME_MONITOR_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.gtk.Private.RemoteVolumeMonitor", NULL);
  if (ret != NULL)
    return GVFS_REMOTE_VOLUME_MONITOR (ret);
  else
    return NULL;
}


/**
 * gvfs_remote_volume_monitor_proxy_new_for_bus:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Like gvfs_remote_volume_monitor_proxy_new() but takes a #GBusType instead of a #GDBusConnection.
 *
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gvfs_remote_volume_monitor_proxy_new_for_bus_finish() to get the result of the operation.
 *
 * See gvfs_remote_volume_monitor_proxy_new_for_bus_sync() for the synchronous, blocking version of this constructor.
 */
void
gvfs_remote_volume_monitor_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (GVFS_TYPE_REMOTE_VOLUME_MONITOR_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.gtk.Private.RemoteVolumeMonitor", NULL);
}

/**
 * gvfs_remote_volume_monitor_proxy_new_for_bus_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gvfs_remote_volume_monitor_proxy_new_for_bus().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with gvfs_remote_volume_monitor_proxy_new_for_bus().
 *
 * Returns: (transfer full) (type GVfsRemoteVolumeMonitorProxy): The constructed proxy object or %NULL if @error is set.
 */
GVfsRemoteVolumeMonitor *
gvfs_remote_volume_monitor_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return GVFS_REMOTE_VOLUME_MONITOR (ret);
  else
    return NULL;
}

/**
 * gvfs_remote_volume_monitor_proxy_new_for_bus_sync:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Like gvfs_remote_volume_monitor_proxy_new_sync() but takes a #GBusType instead of a #GDBusConnection.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See gvfs_remote_volume_monitor_proxy_new_for_bus() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type GVfsRemoteVolumeMonitorProxy): The constructed proxy object or %NULL if @error is set.
 */
GVfsRemoteVolumeMonitor *
gvfs_remote_volume_monitor_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (GVFS_TYPE_REMOTE_VOLUME_MONITOR_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.gtk.Private.RemoteVolumeMonitor", NULL);
  if (ret != NULL)
    return GVFS_REMOTE_VOLUME_MONITOR (ret);
  else
    return NULL;
}


/* ------------------------------------------------------------------------ */

/**
 * GVfsRemoteVolumeMonitorSkeleton:
 *
 * The #GVfsRemoteVolumeMonitorSkeleton structure contains only private data and should only be accessed using the provided API.
 */

/**
 * GVfsRemoteVolumeMonitorSkeletonClass:
 * @parent_class: The parent class.
 *
 * Class structure for #GVfsRemoteVolumeMonitorSkeleton.
 */

struct _GVfsRemoteVolumeMonitorSkeletonPrivate
{
  GValue *properties;
  GList *changed_properties;
  GSource *changed_properties_idle_source;
  GMainContext *context;
  GMutex lock;
};

static void
_gvfs_remote_volume_monitor_skeleton_handle_method_call (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name,
  const gchar *method_name,
  GVariant *parameters,
  GDBusMethodInvocation *invocation,
  gpointer user_data)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (user_data);
  _ExtendedGDBusMethodInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  guint num_params;
  guint num_extra;
  guint n;
  guint signal_id;
  GValue return_value = G_VALUE_INIT;
  info = (_ExtendedGDBusMethodInfo *) g_dbus_method_invocation_get_method_info (invocation);
  g_assert (info != NULL);
  num_params = g_variant_n_children (parameters);
  num_extra = info->pass_fdlist ? 3 : 2;  paramv = g_new0 (GValue, num_params + num_extra);
  n = 0;
  g_value_init (&paramv[n], GVFS_TYPE_REMOTE_VOLUME_MONITOR);
  g_value_set_object (&paramv[n++], skeleton);
  g_value_init (&paramv[n], G_TYPE_DBUS_METHOD_INVOCATION);
  g_value_set_object (&paramv[n++], invocation);
  if (info->pass_fdlist)
    {
#ifdef G_OS_UNIX
      g_value_init (&paramv[n], G_TYPE_UNIX_FD_LIST);
      g_value_set_object (&paramv[n++], g_dbus_message_get_unix_fd_list (g_dbus_method_invocation_get_message (invocation)));
#else
      g_assert_not_reached ();
#endif
    }
  g_variant_iter_init (&iter, parameters);
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.in_args[n - num_extra];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, GVFS_TYPE_REMOTE_VOLUME_MONITOR);
  g_value_init (&return_value, G_TYPE_BOOLEAN);
  g_signal_emitv (paramv, signal_id, 0, &return_value);
  if (!g_value_get_boolean (&return_value))
    g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD, "Method %s is not implemented on interface %s", method_name, interface_name);
  g_value_unset (&return_value);
  for (n = 0; n < num_params + num_extra; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static GVariant *
_gvfs_remote_volume_monitor_skeleton_handle_get_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GError **error,
  gpointer user_data)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  GVariant *ret;
  ret = NULL;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gvfs_remote_volume_monitor_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      g_value_init (&value, pspec->value_type);
      g_object_get_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      ret = g_dbus_gvalue_to_gvariant (&value, G_VARIANT_TYPE (info->parent_struct.signature));
      g_value_unset (&value);
    }
  return ret;
}

static gboolean
_gvfs_remote_volume_monitor_skeleton_handle_set_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GVariant *variant,
  GError **error,
  gpointer user_data)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  gboolean ret;
  ret = FALSE;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gvfs_remote_volume_monitor_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      if (info->use_gvariant)
        g_value_set_variant (&value, variant);
      else
        g_dbus_gvariant_to_gvalue (variant, &value);
      g_object_set_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      g_value_unset (&value);
      ret = TRUE;
    }
  return ret;
}

static const GDBusInterfaceVTable _gvfs_remote_volume_monitor_skeleton_vtable =
{
  _gvfs_remote_volume_monitor_skeleton_handle_method_call,
  _gvfs_remote_volume_monitor_skeleton_handle_get_property,
  _gvfs_remote_volume_monitor_skeleton_handle_set_property,
  {NULL}
};

static GDBusInterfaceInfo *
gvfs_remote_volume_monitor_skeleton_dbus_interface_get_info (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return gvfs_remote_volume_monitor_interface_info ();
}

static GDBusInterfaceVTable *
gvfs_remote_volume_monitor_skeleton_dbus_interface_get_vtable (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return (GDBusInterfaceVTable *) &_gvfs_remote_volume_monitor_skeleton_vtable;
}

static GVariant *
gvfs_remote_volume_monitor_skeleton_dbus_interface_get_properties (GDBusInterfaceSkeleton *_skeleton)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (_skeleton);

  GVariantBuilder builder;
  guint n;
  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
  if (_gvfs_remote_volume_monitor_interface_info.parent_struct.properties == NULL)
    goto out;
  for (n = 0; _gvfs_remote_volume_monitor_interface_info.parent_struct.properties[n] != NULL; n++)
    {
      GDBusPropertyInfo *info = _gvfs_remote_volume_monitor_interface_info.parent_struct.properties[n];
      if (info->flags & G_DBUS_PROPERTY_INFO_FLAGS_READABLE)
        {
          GVariant *value;
          value = _gvfs_remote_volume_monitor_skeleton_handle_get_property (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)), NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", info->name, NULL, skeleton);
          if (value != NULL)
            {
              g_variant_take_ref (value);
              g_variant_builder_add (&builder, "{sv}", info->name, value);
              g_variant_unref (value);
            }
        }
    }
out:
  return g_variant_builder_end (&builder);
}

static void
gvfs_remote_volume_monitor_skeleton_dbus_interface_flush (GDBusInterfaceSkeleton *_skeleton)
{
}

static void
_gvfs_remote_volume_monitor_on_signal_drive_changed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssbbbbbbbbuasa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_drive));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "DriveChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_drive_connected (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssbbbbbbbbuasa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_drive));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "DriveConnected",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_drive_disconnected (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssbbbbbbbbuasa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_drive));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "DriveDisconnected",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_drive_eject_button (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssbbbbbbbbuasa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_drive));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "DriveEjectButton",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_drive_stop_button (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_drive)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssbbbbbbbbuasa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_drive));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "DriveStopButton",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_volume_changed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_volume)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbbssa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_volume));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "VolumeChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_volume_added (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_volume)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbbssa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_volume));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "VolumeAdded",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_volume_removed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_volume)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbbssa{ss}sa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_volume));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "VolumeRemoved",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_changed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbsassa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_mount));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_added (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbsassa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_mount));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountAdded",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_pre_unmount (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbsassa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_mount));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountPreUnmount",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_removed (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    GVariant *arg_mount)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss@(ssssssbsassa{sv}))",
                   arg_dbus_name,
                   arg_id,
                   arg_mount));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountRemoved",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_op_ask_password (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    const gchar *arg_default_user,
    const gchar *arg_default_domain,
    guint arg_flags)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(sssssu)",
                   arg_dbus_name,
                   arg_id,
                   arg_message_to_show,
                   arg_default_user,
                   arg_default_domain,
                   arg_flags));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountOpAskPassword",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_op_ask_question (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    const gchar *const *arg_choices)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(sss^as)",
                   arg_dbus_name,
                   arg_id,
                   arg_message_to_show,
                   arg_choices));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountOpAskQuestion",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_op_show_processes (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    GVariant *arg_pid,
    const gchar *const *arg_choices)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(sss@ai^as)",
                   arg_dbus_name,
                   arg_id,
                   arg_message_to_show,
                   arg_pid,
                   arg_choices));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountOpShowProcesses",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_op_show_unmount_progress (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id,
    const gchar *arg_message_to_show,
    gint64 arg_time_left,
    gint64 arg_bytes_left)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(sssxx)",
                   arg_dbus_name,
                   arg_id,
                   arg_message_to_show,
                   arg_time_left,
                   arg_bytes_left));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountOpShowUnmountProgress",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gvfs_remote_volume_monitor_on_signal_mount_op_aborted (
    GVfsRemoteVolumeMonitor *object,
    const gchar *arg_dbus_name,
    const gchar *arg_id)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss)",
                   arg_dbus_name,
                   arg_id));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gtk.Private.RemoteVolumeMonitor", "MountOpAborted",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void gvfs_remote_volume_monitor_skeleton_iface_init (GVfsRemoteVolumeMonitorIface *iface);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (GVfsRemoteVolumeMonitorSkeleton, gvfs_remote_volume_monitor_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_ADD_PRIVATE (GVfsRemoteVolumeMonitorSkeleton)
                         G_IMPLEMENT_INTERFACE (GVFS_TYPE_REMOTE_VOLUME_MONITOR, gvfs_remote_volume_monitor_skeleton_iface_init));

#else
G_DEFINE_TYPE_WITH_CODE (GVfsRemoteVolumeMonitorSkeleton, gvfs_remote_volume_monitor_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_IMPLEMENT_INTERFACE (GVFS_TYPE_REMOTE_VOLUME_MONITOR, gvfs_remote_volume_monitor_skeleton_iface_init));

#endif
static void
gvfs_remote_volume_monitor_skeleton_finalize (GObject *object)
{
  GVfsRemoteVolumeMonitorSkeleton *skeleton = GVFS_REMOTE_VOLUME_MONITOR_SKELETON (object);
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    g_source_destroy (skeleton->priv->changed_properties_idle_source);
  g_main_context_unref (skeleton->priv->context);
  g_mutex_clear (&skeleton->priv->lock);
  G_OBJECT_CLASS (gvfs_remote_volume_monitor_skeleton_parent_class)->finalize (object);
}

static void
gvfs_remote_volume_monitor_skeleton_init (GVfsRemoteVolumeMonitorSkeleton *skeleton)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  skeleton->priv = gvfs_remote_volume_monitor_skeleton_get_instance_private (skeleton);
#else
  skeleton->priv = G_TYPE_INSTANCE_GET_PRIVATE (skeleton, GVFS_TYPE_REMOTE_VOLUME_MONITOR_SKELETON, GVfsRemoteVolumeMonitorSkeletonPrivate);
#endif

  g_mutex_init (&skeleton->priv->lock);
  skeleton->priv->context = g_main_context_ref_thread_default ();
}

static void
gvfs_remote_volume_monitor_skeleton_class_init (GVfsRemoteVolumeMonitorSkeletonClass *klass)
{
  GObjectClass *gobject_class;
  GDBusInterfaceSkeletonClass *skeleton_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize = gvfs_remote_volume_monitor_skeleton_finalize;

  skeleton_class = G_DBUS_INTERFACE_SKELETON_CLASS (klass);
  skeleton_class->get_info = gvfs_remote_volume_monitor_skeleton_dbus_interface_get_info;
  skeleton_class->get_properties = gvfs_remote_volume_monitor_skeleton_dbus_interface_get_properties;
  skeleton_class->flush = gvfs_remote_volume_monitor_skeleton_dbus_interface_flush;
  skeleton_class->get_vtable = gvfs_remote_volume_monitor_skeleton_dbus_interface_get_vtable;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (GVfsRemoteVolumeMonitorSkeletonPrivate));
#endif
}

static void
gvfs_remote_volume_monitor_skeleton_iface_init (GVfsRemoteVolumeMonitorIface *iface)
{
  iface->drive_changed = _gvfs_remote_volume_monitor_on_signal_drive_changed;
  iface->drive_connected = _gvfs_remote_volume_monitor_on_signal_drive_connected;
  iface->drive_disconnected = _gvfs_remote_volume_monitor_on_signal_drive_disconnected;
  iface->drive_eject_button = _gvfs_remote_volume_monitor_on_signal_drive_eject_button;
  iface->drive_stop_button = _gvfs_remote_volume_monitor_on_signal_drive_stop_button;
  iface->volume_changed = _gvfs_remote_volume_monitor_on_signal_volume_changed;
  iface->volume_added = _gvfs_remote_volume_monitor_on_signal_volume_added;
  iface->volume_removed = _gvfs_remote_volume_monitor_on_signal_volume_removed;
  iface->mount_changed = _gvfs_remote_volume_monitor_on_signal_mount_changed;
  iface->mount_added = _gvfs_remote_volume_monitor_on_signal_mount_added;
  iface->mount_pre_unmount = _gvfs_remote_volume_monitor_on_signal_mount_pre_unmount;
  iface->mount_removed = _gvfs_remote_volume_monitor_on_signal_mount_removed;
  iface->mount_op_ask_password = _gvfs_remote_volume_monitor_on_signal_mount_op_ask_password;
  iface->mount_op_ask_question = _gvfs_remote_volume_monitor_on_signal_mount_op_ask_question;
  iface->mount_op_show_processes = _gvfs_remote_volume_monitor_on_signal_mount_op_show_processes;
  iface->mount_op_show_unmount_progress = _gvfs_remote_volume_monitor_on_signal_mount_op_show_unmount_progress;
  iface->mount_op_aborted = _gvfs_remote_volume_monitor_on_signal_mount_op_aborted;
}

/**
 * gvfs_remote_volume_monitor_skeleton_new:
 *
 * Creates a skeleton object for the D-Bus interface <link linkend="gdbus-interface-org-gtk-Private-RemoteVolumeMonitor.top_of_page">org.gtk.Private.RemoteVolumeMonitor</link>.
 *
 * Returns: (transfer full) (type GVfsRemoteVolumeMonitorSkeleton): The skeleton object.
 */
GVfsRemoteVolumeMonitor *
gvfs_remote_volume_monitor_skeleton_new (void)
{
  return GVFS_REMOTE_VOLUME_MONITOR (g_object_new (GVFS_TYPE_REMOTE_VOLUME_MONITOR_SKELETON, NULL));
}

